﻿//////////////////////////////////////////////////////////////////////////////////////////
//                                                                                      //
//  Anwendung                                                                           //
//  _________________________________                                                   //
//                                                                                      //
//  Copyright (c) 2018 Reimar Grasbon                                                   //
//                                                                                      //
//////////////////////////////////////////////////////////////////////////////////////////
//                                                                                      //
//  This software is subjected to the FreeBSD License. Redistribution and use in source //
//  and binary forms, with or without modification, are permitted provided that the     //
//  following conditions are met:                                                       //
//                                                                                      //
//  1. Redistributions of source code must retain the above copyright notice, this list //
//     of conditions and the following disclaimer.                                      //
//                                                                                      //
//  2. Redistributions in binary form must reproduce the above copyright notice, this   //
//     list of conditions and the following disclaimer in the documentation and/or      //
//     other materials provided with the distribution.                                  //
//                                                                                      //
//  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY //
//  EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED           //
//  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  //
//  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,    //
//  INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT  //
//  NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR  //
//  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,   //
//  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)  //
//  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE          //
//  POSSIBILITY OF SUCH DAMAGE.                                                         //
//                                                                                      //
//////////////////////////////////////////////////////////////////////////////////////////

#pragma once

#include "Conf.h"
#include "TypeDefs.h"
#include "LightSignal.h"
#include "ToneSignal.h"
#include "PushMessage.h"
#include "TextFeed.h"

//////////////////////////////////////////////////////////////////////////////////////////
//  Definitionen  ////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////
#define AUTO_TIMER_INVALID  {   false,                                       \
	TIME_INVALID,                                \
	TIME_INVALID,                                \
	{ true, true, true, true, true, true, true } \
}

//////////////////////////////////////////////////////////////////////////////////////////
//  Typen  ///////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////
typedef enum							     // Signale der System-LED
{   SYSTEM_LED_SIGNAL_OFF			    = 0, // · Kein Signal, Ausgeschaltet
	SYSTEM_LED_SIGNAL_ON				= 1, // · Leuchtet durchgehend
	SYSTEM_LED_SIGNAL_HEARTBEAT		    = 2, // · Herzschlag-Signal
	SYSTEM_LED_SIGNAL_BUS_ACT           = 3, // · Zeigt Aktivität auf dem Bus
	SYSTEM_LED_SIGNAL_HEARTBEAT_BUS_ACT = 4  // · Zeigt Herzschlag-Signal und Bus-Aktivität
} SystemLedSignal;

typedef struct                      // Kontakt-Zustandssignal:
{	ToneStateSignal	  toneSignal;	// · Tonsignal bei Eintritt des Zustandes
	LightStateSignal  lightSignal;	// · Lichtsignal bei Eintritt des Zustandes	
	UInt08            brightness;   // · Helligkeit des Lichtsignals
} ContactStateSignal;

typedef struct                      // Konfiguration der Kontakt-Ereignisse:
{   UInt08            duration;     // · Zustandsdauer bis Ereignis eintritt
	ToneEventSignal   toneSignal;	// · Tonsignal bei Eintritt des Ereignisses
	LightEventSignal  lightSignal;  // · Lichtsignal bei Eintritt des Ereignisses	
	UInt08            brightness;   // · Helligkeit des Lichtsignals
    PushMessage       pushMessage;  // · Push-Nachricht bei Eintritt des Ereignisses
    TextFeed          textFeed;     // · Rundmitteilungstext bei Eintritt des Ereignisses	
} ContactEventConfiguration;

typedef enum
{   SWITCH_MODE_OFF        = 0,
	SWITCH_MODE_ON         = 1,
	SWITCH_MODE_TIMER      = 2,
	SWITCH_MODE_BRIGHTNESS = 3
} SwitchMode;

typedef enum
{   BRIGHTNESS_MODE_LIGHT_OFF_DARK_ON = 0,
	BRIGHTNESS_MODE_LIGHT_ON_DARK_OFF = 1
} BrightnessMode;

typedef struct
{   bool     enabled;
	Time     startTime;
	Time     endTime;
	bool     weekDay[7];
} AutoTimer;

typedef struct                      // Bus-Aktivitätsanzeige auf der LED:
{	bool			  enabled;		// · 'true' = ein
	UInt08			  brightness;	// · Helligkeit: 10% .. 100%
} LedBusActivity;

//////////////////////////////////////////////////////////////////////////////////////////
//  Prozessaufrufe  //////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////
void          APPLICATION_Startup(void);
void          APPLICATION_Proceed(void);
void          APPLICATION_Shutdown(void);

//////////////////////////////////////////////////////////////////////////////////////////

