﻿//////////////////////////////////////////////////////////////////////////////////////////
//                                                                                      //
//  Push-Nachricht                                                                      //
//  _________________________________                                                   //
//                                                                                      //
//  Copyright (c) 2019 Reimar Grasbon                                                   //
//                                                                                      //
//////////////////////////////////////////////////////////////////////////////////////////
//                                                                                      //
//  This software is subjected to the FreeBSD License. Redistribution and use in source //
//  and binary forms, with or without modification, are permitted provided that the     //
//  following conditions are met:                                                       //
//                                                                                      //
//  1. Redistributions of source code must retain the above copyright notice, this list //
//     of conditions and the following disclaimer.                                      //
//                                                                                      //
//  2. Redistributions in binary form must reproduce the above copyright notice, this   //
//     list of conditions and the following disclaimer in the documentation and/or      //
//     other materials provided with the distribution.                                  //
//                                                                                      //
//  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY //
//  EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED           //
//  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  //
//  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,    //
//  INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT  //
//  NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR  //
//  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,   //
//  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)  //
//  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE          //
//  POSSIBILITY OF SUCH DAMAGE.                                                         //
//                                                                                      //
//////////////////////////////////////////////////////////////////////////////////////////

#include "PushMessage.h"
#include "Storing.h"

//////////////////////////////////////////////////////////////////////////////////////////
//  Funktionen  //////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////
bool
PUSHMESSAGE_IsValid(const PushMessage* pushMessage)
{
    return CY4ADDRESS_IsValid(&pushMessage->address) && pushMessage->location < 0x1000000;
}

//////////////////////////////////////////////////////////////////////////////////////////
void
PUSHMESSAGE_FromData(const UInt08* data, PushMessage* pushMessage)
{
    pushMessage->address  = CY4ADDRESS_Create(data[0], data[1]);
    pushMessage->location = ((UInt32)data[2] << 16) +
                            ((UInt16)data[3] <<  8) +
                            (        data[4] <<  0);
    pushMessage->payload  = data[5];
}

//////////////////////////////////////////////////////////////////////////////////////////
void
PUSHMESSAGE_ToData(const PushMessage* pushMessage, UInt08* data)
{
    data[0] = CY4ADDRESS_Net(&pushMessage->address);
    data[1] = CY4ADDRESS_Dev(&pushMessage->address);
    data[2] = (UInt08)(pushMessage->location >> 16);
    data[3] = (UInt08)(pushMessage->location >>  8);
    data[4] = (UInt08)(pushMessage->location >>  0);
    data[5] = pushMessage->payload;
}

//////////////////////////////////////////////////////////////////////////////////////////
void
PUSHMESSAGE_ToMessage(const PushMessage* pushMessage, Cy4Message* message)
{
    if (!PUSHMESSAGE_IsValid(pushMessage)) return;
    CY4MESSAGE_SetupWrite(message, pushMessage->address,
                                   pushMessage->location,
                                   &pushMessage->payload,
                                   1);
}

//////////////////////////////////////////////////////////////////////////////////////////
void
PUSHMESSAGE_EEPLoad(const PushMessage* eepPushMessage, PushMessage* pushMessage)
{
    STORING_LoadEEPMem(eepPushMessage, pushMessage, sizeof(PushMessage));
}

//////////////////////////////////////////////////////////////////////////////////////////
void
PUSHMESSAGE_EEPSave(const PushMessage* pushMessage, PushMessage* eepPushMessage)
{
    STORING_SaveEEPMem(pushMessage, eepPushMessage, sizeof(PushMessage));
}

//////////////////////////////////////////////////////////////////////////////////////////
