﻿//////////////////////////////////////////////////////////////////////////////////////////
//                                                                                      //
//  Rundmitteilung                                                                      //
//  _________________________________                                                   //
//                                                                                      //
//  Copyright (c) 2019 Reimar Grasbon                                                   //
//                                                                                      //
//////////////////////////////////////////////////////////////////////////////////////////
//                                                                                      //
//  This software is subjected to the FreeBSD License. Redistribution and use in source //
//  and binary forms, with or without modification, are permitted provided that the     //
//  following conditions are met:                                                       //
//                                                                                      //
//  1. Redistributions of source code must retain the above copyright notice, this list //
//     of conditions and the following disclaimer.                                      //
//                                                                                      //
//  2. Redistributions in binary form must reproduce the above copyright notice, this   //
//     list of conditions and the following disclaimer in the documentation and/or      //
//     other materials provided with the distribution.                                  //
//                                                                                      //
//  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY //
//  EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED           //
//  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  //
//  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,    //
//  INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT  //
//  NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR  //
//  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,   //
//  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)  //
//  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE          //
//  POSSIBILITY OF SUCH DAMAGE.                                                         //
//                                                                                      //
//////////////////////////////////////////////////////////////////////////////////////////

#include "TextFeed.h"
#include "Storing.h"

//////////////////////////////////////////////////////////////////////////////////////////
//  Lokale Funktionen  ///////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////
void
Copy(const UInt08* from, UInt08* to)
{
    UInt08 i;
    for (i=0; i<sizeof(((const TextFeed*)0)->text)-1; i++)
    {   UInt08 c = from[i];
        if(c == 0) break;
        to[i] = c;
    }
    to[i] = 0;
}

//////////////////////////////////////////////////////////////////////////////////////////
UInt08
Length(const TextFeed* textFeed)
{
    UInt08 length;
    for (length=0; length<sizeof(((const TextFeed*)0)->text)-1; length++)
    {   if (textFeed->text[length] == 0) break;
    }
    return length;
}

//////////////////////////////////////////////////////////////////////////////////////////
//  Funktionen  //////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////
bool
TEXTFEED_IsEmpty(const TextFeed* textFeed)
{
    return Length(textFeed) == 0;
}

//////////////////////////////////////////////////////////////////////////////////////////
void
TEXTFEED_FromData(const UInt08* data, TextFeed* textFeed)
{
    Copy(data, textFeed->text);
}

//////////////////////////////////////////////////////////////////////////////////////////
void
TEXTFEED_ToData(const TextFeed* textFeed, UInt08* data)	// sizeof(data) == 51 !
{
    Copy(textFeed->text, data);
}

//////////////////////////////////////////////////////////////////////////////////////////
void
TEXTFEED_ToMessage(const TextFeed* textFeed, Cy4Message* message)
{
    UInt08 length = Length(textFeed);
    if (length == 0) return;
    Cy4Address  address = CY4ADDRESS(0,0);  // Allgemeiner Rundruf
    CY4MESSAGE_SetupWrite(message, address, 0xE00100, textFeed->text, length+1);
}

//////////////////////////////////////////////////////////////////////////////////////////
void
TEXTFEED_EEPLoad(const TextFeed* eepTextFeed, TextFeed* textFeed)
{
    STORING_LoadEEPMem(eepTextFeed, textFeed, sizeof(TextFeed));
}

//////////////////////////////////////////////////////////////////////////////////////////
void
TEXTFEED_EEPSave(const TextFeed* textFeed, TextFeed* eepTextFeed)
{
    STORING_SaveEEPMem(textFeed, eepTextFeed, sizeof(TextFeed));
}

//////////////////////////////////////////////////////////////////////////////////////////
